package com.dashitech.migration.task.category;

import com.dashitech.migration.BaseTask;
import com.dashitech.migration.core.FieldMapper;
import com.dashitech.migration.task.other.DictionaryTask;
import com.dashitech.migration.task.uc.GroupTask;
import com.dashitech.migration.task.uc.HospitalTask;
import com.dashitech.migration.task.uc.UserTask;
import com.dashitech.migration.util.JdbcUtil;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;
import java.util.Map;

/**
 * @author song
 * @date 2024年10月12日
 */
@Component
public class IncidentCategoryConfigTask extends BaseTask {

    public static Log log = LogFactory.getLog(IncidentCategoryConfigTask.class);

    @Autowired
    private DictionaryTask dictionaryTask;

    @Autowired
    private GroupTask groupTask;

    @Autowired
    private UserTask userTask;

    @Autowired
    private HospitalTask hospitalTask;

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void start() {
        StringBuffer sql = new StringBuffer("SELECT a.version,a.category_id,b._priority as priority,a.duty_id,a.branch_user_group_type as user_group,a.group_id,");
        sql.append("a.user_id,NOW() as add_time,IF(a.branch_id=4,3,a.branch_id) as hos_id FROM itsm_incident_category_usergroup a ");
        sql.append(" JOIN itsm_incident_category b ON a.category_id = b.id where a.duty_id is not null ");
        if ("xiangyang".equals(appName)) {
            sql.append(" and a.duty_id not in (4,5,6,13,15,19,20,21) ");
        }
        List<Map<String, Object>> categoryConfigList = jdbcTemplateMdv2.queryForList(sql.toString());
        //查询故障现象表的配置数据 组数据 信息中心
        sql = new StringBuffer("select a.version,a.id as category_id,_priority as priority,b.id as duty_id,userOrGroupType as user_group,_group as group_id,");
        sql.append("handle_user as user_id,NOW() as add_time,c.id as hos_id FROM itsm_incident_category a ");
        if ("xiangyang".equals(appName)) {
            sql.append(" join itsm_uc_duty_dept b join itsm_uc_branch c ");
        }
        sql.append(" where`branch_type` = '0' and duty_dept in (2,8,11) AND a.delete_flag = 0 ");
        if ("xiangyang".equals(appName)) {
            sql.append(" and b.id in (11) and c.id in (1,2,3)");
        }
        List<Map<String, Object>> list = jdbcTemplateMdv2.queryForList(sql.toString());
        categoryConfigList.addAll(list);

        FieldMapper mapper = new FieldMapper();
        mapper.addOperationAdd("score", getDicId(jdbcTemplateHsms,"incident_category_score","1"));
        mapper.addOperationReplace("priority", dictionaryTask.loadCache().getIdCache());
        mapper.addOperationReplace("duty_id", hospitalTask.loadCache().getIdCache());
        mapper.addOperationReplace("group_id", groupTask.loadCache().getIdCache());
        mapper.addOperationReplace("user_id", userTask.loadCache().getIdCache());
        mapper.trans2JdbcRow(categoryConfigList);

        JdbcUtil jdbcUtil = new JdbcUtil(jdbcTemplateHsms);
        jdbcUtil.batchPageInsert("itsm_itsm_incident_category_config", mapper.getRows());

        //当院区为空时 将责任科室父级院区赋值
        StringBuffer upSql = new StringBuffer("update `itsm_itsm_incident_category_config` a,itsm_uc_hospital b set hos_id = b.parentId where a.duty_id = b.id and a.hos_id is null ");
        jdbcTemplateHsms.execute(upSql.toString());
        mapper.clear();
    }

    @Override
    public FieldMapper loadCache() {
        return null;
    }
}
