package com.dashitech.migration.task.incident;

import com.dashitech.migration.BaseTask;
import com.dashitech.migration.SqlTask;
import com.dashitech.migration.core.FieldMapper;
import com.dashitech.migration.util.JdbcUtil;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * Created by CX on 2024/10/10.
 */
@Component
public class IncidentAssignManagerTask extends BaseTask {

    @Autowired
    SqlTask hospitalTask;

    @Autowired
    SqlTask departmentTask;

    @Autowired
    SqlTask userTask;

    @Autowired
    SqlTask groupTask;

    public static Log log = LogFactory.getLog(IncidentAssignManagerTask.class);

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void start() {
        log.info(" *** IncidentAssignManagerTask start 开始 *** ");

        StringBuffer sb = new StringBuffer();
        sb.append("SELECT version,dept_id,category_id,handle_user,IFNULL(_group,b.group_id) as handle_group,add_time,");
        sb.append("a.duty_id as hos_id,batch_id as batch_no  FROM `itsm_incident_assign_manager` a left join ");
        sb.append("(select a.user_id,a.group_id,b.duty_id from itsm_uc_user_group a join itsm_uc_groups b on a.group_id = b.id ) b ");
        sb.append("on a.handle_user = b.user_id and a.duty_id = b.duty_id");

        List list = jdbcTemplateMdv2.queryForList(sb.toString());

        FieldMapper mapper = new FieldMapper();
        mapper.addOperationReplace("hos_id", hospitalTask.loadCache().getIdCache());
        if ("xiangyang".equals(appName)) {
            mapper.addOperationReplace("dept_id", departmentTask.loadCache().getIdCache());
        }
        mapper.addOperationReplace("handle_user", userTask.loadCache().getIdCache());
        mapper.addOperationReplace("handle_group", groupTask.loadCache().getIdCache());
        mapper.trans2JdbcRow(list);

        JdbcUtil jdbcUtil = new JdbcUtil(jdbcTemplateHsms);
        jdbcUtil.batchPageInsert("itsm_itsm_incident_assign_manager", mapper.getRows());

        //clear释放内存
        mapper.clear();
    }

    @Override
    public FieldMapper loadCache() {
        log.info(" *** IncidentAssignManagerTask loadCache 开始 *** ");


        return null;
    }
}
