package com.dashitech.migration.task.uc;

import com.dashitech.migration.BaseTask;
import com.dashitech.migration.SqlTask;
import com.dashitech.migration.core.DataMigrationter;
import com.dashitech.migration.core.FieldMapper;
import com.dashitech.migration.core.RowsWrap;
import com.dashitech.migration.util.JdbcRow;
import com.dashitech.migration.util.JdbcUtil;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * Created by CX on 2024/10/10.
 */
@Component
public class UserTask extends BaseTask {

    @Autowired
    SqlTask hospitalTask;
    @Autowired
    SqlTask departmentTask;
    @Autowired
    SqlTask dictionaryTask;
    @Autowired
    SqlTask companyTask;

    public static Log log = LogFactory.getLog(UserTask.class);

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void start() {
        log.info(" *** 用户user转换开始 *** ");

        StringBuffer sb = new StringBuffer();
        sb.append(" select version,GENDER,NAME,PHONE,PWD,WEIXIN,DEPTID,delete_flag, ");
        sb.append(" pinyin,py as 'input_code',online, ");
        if ("xiangyang".equals(appName)) {
            sb.append("IF(branch_id = 4 or branch_id is null,3,branch_id)  as 'hospital_id',");
            sb.append("case when ACCOUNT = '80185' then 'DuBinBin' when ACCOUNT = '001550' then '1550' ");
            sb.append("when ACCOUNT = '001551' then '1551' when ACCOUNT = '001552' then '1552' ");
            sb.append("when ACCOUNT in ('0011769','001769') then '1769' when ACCOUNT in ('0015667','015667','005667') then '5667' ");
            sb.append("when ACCOUNT in('001811','00001811','0011811','01811') then '1811' else ACCOUNT end as ACCOUNT,");
        } else {
            sb.append("duty_id as 'hospital_id',ACCOUNT,");
        }
        sb.append(" duty_id as 'duty_dept',company as 'company_id',engineer ");
        sb.append(" from itsm_uc_user ");
        sb.append(" where ACCOUNT != 'dsadmin' ");

        List list = jdbcTemplateMdv2.queryForList(sb.toString());

        FieldMapper mapper = new FieldMapper();
        mapper.addOperationAdd("usertype", getDicId(jdbcTemplateHsms,"usertype","4")); //用户类型-默认三方人员
        mapper.addOperationReplace("duty_dept", hospitalTask.loadCache().getIdCache());
        mapper.addOperationReplace("GENDER", dictionaryTask.loadCache().getIdCache());
        mapper.addOperationReplace("company_id", companyTask.loadCache().getIdCache());
        if ("xiangyang".equals(appName)) {
            mapper.addOperationReplace("DEPTID", departmentTask.loadCache().getIdCache());
        } else {
            mapper.addOperationReplace("hospital_id", hospitalTask.loadCache().getIdCache());
        }
        mapper.trans2JdbcRow(list);

        FieldMapper userMapper = loadCache();
        RowsWrap rw = DataMigrationter.getRowsWrap(mapper,userMapper);
        JdbcUtil jdbcUtil = new JdbcUtil(jdbcTemplateHsms);
        jdbcUtil.batchPageInsert("itsm_uc_user", rw.getInsertRows());
        List<JdbcRow> updateRows = rw.getUpdateRows();
        //过滤微信不为空的数据做更新处理
        updateRows = updateRows.stream().filter(s -> s.getRow().get("WEIXIN") != null).collect(Collectors.toList());
        //筛选出运维人员做更新
        updateRows = updateRows.stream().filter(s -> s.getRow().get("engineer") != null && "1".equals(s.getRow().get("engineer").toString())).collect(Collectors.toList());
        jdbcUtil.batchPageUpdate("itsm_uc_user", updateRows);

        //性别有null的
        String sql = " update itsm_uc_user SET GENDER = (SELECT id from itsm_base_dictionary WHERE _key = 'user_gender' and _value = '0' ) WHERE GENDER is null ";
        jdbcTemplateHsms.execute(sql);

        if ("xiangyang".equals(appName)) {
            //襄阳删除运维人员的护士角色
            sql = "DELETE from itsm_uc_user_role where user_id in (select id from itsm_uc_user where usertype = (select id from itsm_base_dictionary where _key = 'usertype' and _value = '4')) and role_id = 3";
            jdbcTemplateHsms.execute(sql);

            //修改运维人员账号为默认密码
            sql = "update itsm_uc_user set PWD = '21218CCA77804D2BA1922C33E0151105' where usertype = (select id from itsm_base_dictionary where _key = 'usertype' and _value = '4') ";
            jdbcTemplateHsms.execute(sql);
        }

        //clear释放内存
        mapper.clear();
        userMapper.clear();
    }

    @Override
    public FieldMapper loadCache() {
        log.info(" *** 加载用户user缓存 *** ");

        String sql = " select id,ACCOUNT,delete_flag from itsm_uc_user ";
        List<Map<String, Object>> list = jdbcTemplateHsms.queryForList(sql);
        sql = " select id,ACCOUNT,delete_flag from itsm_uc_user ";
        List<Map<String, Object>> list2 = jdbcTemplateMdv2.queryForList(sql);

        FieldMapper mapper = new FieldMapper();
        mapper.addFieldMapper("ACCOUNT", "ACCOUNT");
        mapper.addFieldMapper("delete_flag", "delete_flag");

        DataMigrationter.loadCache(list, list2, mapper);

        return mapper;
    }
}
